@@ -51,10 +51,10 @@ struct _EmpathyEventManagerClass {
 typedef enum {
     EMPATHY_EVENT_TYPE_CHAT,
     EMPATHY_EVENT_TYPE_VOIP,
-    EMPATHY_EVENT_TYPE_CALL,
     EMPATHY_EVENT_TYPE_TRANSFER,
     EMPATHY_EVENT_TYPE_SUBSCRIPTION,
-    EMPATHY_EVENT_TYPE_PRESENCE,
+    EMPATHY_EVENT_TYPE_PRESENCE_ONLINE,
+    EMPATHY_EVENT_TYPE_PRESENCE_OFFLINE,
     EMPATHY_EVENT_TYPE_INVITATION,
     EMPATHY_EVENT_TYPE_AUTH,
 } EmpathyEventType;
@@ -67,7 +67,6 @@ typedef struct {
     gchar *header;
     gchar *message;
     gboolean must_ack;
-    GObject *handler_instance;
 } EmpathyEvent;
 
 GType                empathy_event_manager_get_type      (void) G_GNUC_CONST;
@@ -78,6 +77,7 @@ void                 empathy_event_activate              (EmpathyEvent        *e
 void                 empathy_event_inhibit_updates       (EmpathyEvent        *event);
 void                 empathy_event_approve               (EmpathyEvent        *event);
 void                 empathy_event_decline               (EmpathyEvent        *event);
+void                 empathy_event_remove                (EmpathyEvent        *event);
 
 G_END_DECLS
 
